@@ -61,7 +61,7 @@ class GSPeerConnectionBroadcaster:
                     )
                 elif platform.system() == "Windows":
                     webcam = MediaPlayer(
-                        f"video=f{self.gsdbs.credentials['device']}", format="dshow", options=options
+                        f"video={self.gsdbs.credentials['device']}", format="dshow", options=options
                     )
                 else:
                     webcam = MediaPlayer(f"{self.gsdbs.credentials['device']}", format="v4l2", options=options)
